@@ -140,8 +140,10 @@ class Veloce(NodeVisitor):
             varkwargs = '__kwargs'
 
         # unpack arguments
-        self.writer.write('var __args = Array.prototype.slice.call(arguments);')
-        self.writer.write('var {} = __args[__args.length - 1];'.format(varkwargs))
+        if varargs or varkwargs != '__kwargs':
+            self.writer.write('var __args = Array.prototype.slice.call(arguments);')
+        if varkwargs != '__kwargs':
+            self.writer.write('var {} = __args[__args.length - 1];'.format(varkwargs))
         for keyword in kwargs.keys():
             self.writer.write('{} = {} || {}.{} || {};'.format(keyword, keyword, varkwargs, keyword, kwargs[keyword]))
             self.writer.write('delete {}.{};'.format(varkwargs, keyword))
@@ -156,8 +158,9 @@ class Veloce(NodeVisitor):
                 if isinstance(n, Assign) and isinstance(n.targets[0], Name):
                     local_vars.add(n.targets[0].id)
                 elif isinstance(n, Assign) and isinstance(n.targets[0], Tuple):
-                    for target in n.targets[0].elts:
-                        local_vars.add(target.id)
+                    for target in n.targets:
+                        for target in target.elts:
+                            local_vars.add(target.id)
                 elif isinstance(n, Global):
                     global_vars.update(n.names)
                 elif hasattr(n, 'body') and not isinstance(n, FunctionDef):
@@ -218,7 +221,7 @@ class Veloce(NodeVisitor):
 
     def visit_Attribute(self, node):
         name = self.visit(node.value)
-        attr = node.attr
+        attr = node.attr.replace('__DOLLAR__', '$')
         return '{}.{}'.format(name, attr)
 
     def visit_keyword(self, node):
@@ -404,34 +407,33 @@ class Veloce(NodeVisitor):
         return '||'
 
     def visit_Assign(self, node):
-        # XXX: I'm not sure why it is a list since, mutiple targets are inside a tuple
         target = node.targets[0]
-        if isinstance(target, Tuple):
-            targets = map(self.visit, target.elts)
-            value = self.visit(node.value)
-            self.writer.write('var __targets = {};\n'.format(value))
-            for index, target in enumerate(targets):
-                self.writer.write('{} = __targets[{}];\n'.format(target, index))
-        else:
-            target = self.visit(target)
-            value = self.visit(node.value)
-            if self.in_classdef and len(self._function_stack) == 0:
-                self.writer.write('{}: {},'.format(target, value))
+        value = self.visit(node.value)
+        self.writer.write('var __assignement = {};'.format(value))
+        for target in node.targets:
+            if isinstance(target, Tuple):
+                targets = map(self.visit, target.elts)
+                for index, target in enumerate(targets):
+                    self.writer.write('{} = __assignement[{}];\n'.format(target, index))
             else:
-                if target == '__all__':
-                    if isinstance(node.value, Name):
-                        self.__all__ = value
-                    elif isinstance(node.value, Str):
-                        self.__all__ = node.value.s
-                    elif isinstance(node.value, List):
-                        if isinstance(node.value.elts[0], Name):
-                            self.__all__ = list(map(self.visit, node.value.elts))
-                        else:
-                            self.__all__ = list(map(lambda x: x.s, node.value.elts))
-                    else:
-                        raise NotImplementedError
+                target = self.visit(target)
+                if self.in_classdef and len(self._function_stack) == 0:
+                    self.writer.write('{}: {},'.format(target, value))
                 else:
-                    self.writer.write('{} = {};'.format(target, value))
+                    if target == '__all__':
+                        if isinstance(node.value, Name):
+                            self.__all__ = value
+                        elif isinstance(node.value, Str):
+                            self.__all__ = node.value.s
+                        elif isinstance(node.value, List):
+                            if isinstance(node.value.elts[0], Name):
+                                self.__all__ = list(map(self.visit, node.value.elts))
+                            else:
+                                self.__all__ = list(map(lambda x: x.s, node.value.elts))
+                        else:
+                            raise NotImplementedError
+                    else:
+                        self.writer.write('{} = __assignement;'.format(target))
 
     def visit_Expr(self, node):
         self.writer.write(self.visit(node.value) + ';')
@@ -472,7 +474,7 @@ class Veloce(NodeVisitor):
             self.writer.push()
             list(map(self.visit, node.orelse))
             self.writer.pull()
-            self.write.write('}')
+            self.writer.write('}')
 
     def visit_Dict(self, node):
         a = []
